%define debug_package %{nil}

%global __requires_exclude perl\\(Exporter\\)|perl\\(XSLoader\\)

%define with_docs 1

Summary:	A framework for configuring, compiling and installing applications
Name:		waf
Version:	2.1.5
Release:	%mkrel 1
License:	BSD and Python
Group:		Development/Tools
Url:		https://waf.io/
# Original tarfile can be found at
# https://waf.io/waf-%%{version}.tar.bz2
# We remove docs/book, as this is under CC-BY-NC-ND, which is not
# allowed in Mageia.
# We remove Waf logos ./docs/gfx/waflogo.svg ./docs/slides/presentation/gfx/waflogo.svg ./docs/sphinx/_images/waf-64x64.png
# - Waf logos, licensed CC BY-NC
Source0:	waf-%{version}.stripped.tar.xz
Source1:        macros.waf
Source3:	repack.sh
Patch0:		waf-1.8.11-libdir.patch
Patch1:		waf-1.6.9-logo.patch
Patch2:		waf-1.8.11-sphinx-no-W.patch
Patch3:		pyext-linking.patch
Patch4:		0001-Fix-linking-order-when-linking-C-and-C.patch
BuildArch:	noarch
BuildRequires:	pkgconfig(python3)
%if %{with_docs}
BuildRequires:	python3dist(sphinx)
BuildRequires:	graphviz
BuildRequires:	imagemagick
Recommends:	%{name}-doc
%endif
BuildConflicts:	waf
Requires:	python(abi) = %{python3_version}
Provides:	waf-python3 = %{version}-%{release}

%description
Waf is a Python-based framework for configuring, compiling and installing
applications. It derives from the concepts of other build tools such as
Scons, Autotools, CMake, and Ant.

%if %{with_docs}
%package -n %{name}-doc
Summary:	Documentation for %{name}
Group:		Documentation

%description -n %{name}-doc
Waf is a Python-based framework for configuring, compiling and
installing applications. It is a replacement for other tools such as
Autotools, Scons, CMake or Ant.
This package contains the HTML documentation for %{name}.
%endif

%prep
%autosetup -p1

%build
extras=
for f in waflib/extras/*.py ; do
	f=$(basename "$f" .py);
	if [ "$f" != "__init__" ]; then
		extras="${extras:+$extras,}$f" ;
	fi
done
%{python3} ./waf-light --make-waf --strip --tools="$extras"

%if %{with_docs}
# build html docs
export WAFDIR=$(pwd)
pushd docs/sphinx
%{python3} ../../waf configure build
popd
%endif

%install
# use waf so it unpacks itself
mkdir -p _temp
pushd _temp
  cp -av ../waf .
  %{python3} ./waf >/dev/null 2>&1
  pushd .waf3-%{version}-*
    find . -name '*.py' -printf '%%P\0' |
	xargs -0 -I{} install -m 0644 -p -D {} %{buildroot}%{_datadir}/waf3/{}
  popd
popd

install -m 0755 -p -D waf-light %{buildroot}%{_bindir}/waf-%{python3_version}

ln -s waf-%{python3_version} %{buildroot}%{_bindir}/waf

# remove shebangs from and fix EOL for all scripts in wafadmin
find %{buildroot}%{_datadir}/ -name '*.py' \
	-exec sed -i -e '1{/^#!/d}' -e 's|\r$||g' {} \;

# fix waf script shebang line
%py3_shebang_fix %{buildroot}%{_bindir}/waf-%{python3_version}

# remove x-bits from everything going to doc
find demos utils -type f -exec chmod 0644 {} \;

# remove hidden file
rm -f docs/sphinx/build/html/.buildinfo

# install waf rpm macro helper
install -Dpm644 %{SOURCE1} %{buildroot}%{_rpmmacrodir}/macros.waf

# do byte compilation
%py_byte_compile %{python3} %{buildroot}%{_datadir}/waf3

%if %{with_docs}
%files -n %{name}-doc
%doc docs/sphinx/build/html
%doc README* ChangeLog demos
%endif

%files
%{_rpmmacrodir}/macros.waf
%{_bindir}/%{name}
%{_bindir}/%{name}-%{python3_version}
%{_datadir}/waf3/


%changelog
* Fri Feb 21 2025 daviddavid <daviddavid> 2.1.5-1.mga10
+ Revision: 2150353
- new version: 2.1.5

* Sun Feb 02 2025 wally <wally> 2.1.4-3.mga10
+ Revision: 2144743
- redo linking order patch

* Sun Feb 02 2025 wally <wally> 2.1.4-2.mga10
+ Revision: 2144739
- add patch to fix linking order when building C/C++

* Sat Jan 25 2025 daviddavid <daviddavid> 2.1.4-1.mga10
+ Revision: 2142104
- new version: 2.1.4

* Mon Apr 22 2024 daviddavid <daviddavid> 2.0.27-1.mga10
+ Revision: 2060423
- new version: 2.0.27

* Sat Feb 10 2024 daviddavid <daviddavid> 2.0.26-3.mga10
+ Revision: 2040075
- rebuild again to remove old pkgs

* Sat Dec 09 2023 wally <wally> 2.0.26-2.mga10
+ Revision: 2016154
- rebuild for py3.12

* Fri Sep 01 2023 daviddavid <daviddavid> 2.0.26-1.mga10
+ Revision: 1983279
- new version: 2.0.26

* Wed Jan 11 2023 kekepower <kekepower> 2.0.25-1.mga9
+ Revision: 1932302
- Update to version 2.0.25

* Tue Jul 19 2022 wally <wally> 2.0.24-1.mga9
+ Revision: 1869454
- new version 2.0.24

* Thu Mar 31 2022 umeabot <umeabot> 2.0.23-2.mga9
+ Revision: 1837204
- Mageia 9 Mass Rebuild

* Sun Feb 13 2022 wally <wally> 2.0.23-1.mga9
+ Revision: 1773888
- new version 2.0.23
- rebuild for python3.10

* Mon Mar 15 2021 wally <wally> 2.0.22-1.mga9
+ Revision: 1703621
- new version 2.0.22
- rebuild for python 3.9

* Fri Nov 20 2020 kekepower <kekepower> 2.0.21-1.mga8
+ Revision: 1647893
- Update to version 2.0.21

* Sat Apr 04 2020 kekepower <kekepower> 2.0.20-1.mga8
+ Revision: 1564275
- Update to version 2.0.20

* Tue Feb 18 2020 umeabot <umeabot> 2.0.19-2.mga8
+ Revision: 1539224
- Mageia 8 Mass Rebuild
+ wally <wally>
- update url
- update waf rpm macros

* Wed Dec 04 2019 kekepower <kekepower> 2.0.19-1.mga8
+ Revision: 1464169
- Update to version 2.0.19

* Thu Sep 19 2019 wally <wally> 2.0.18-4.mga8
+ Revision: 1443856
- update waf rpm macros (some pkg builds might fail now as waf macros were changed to be more consistent with other similar macros
- install rpm macros to /usr/lib/rpm/macros.d/

* Thu Sep 19 2019 wally <wally> 2.0.18-3.mga8
+ Revision: 1443833
- add patch to fix linking with python3.8 and our LDFLAGS when checking pyext builds

* Sun Sep 15 2019 wally <wally> 2.0.18-2.mga8
+ Revision: 1441061
- rebuild for python3.8
- drop python2 support

* Tue Jul 16 2019 kekepower <kekepower> 2.0.18-1.mga8
+ Revision: 1421859
- Update to version 2.0.18

* Sun Jun 30 2019 kekepower <kekepower> 2.0.17-1.mga8
+ Revision: 1416313
- Update to version 2.0.17

* Thu May 23 2019 kekepower <kekepower> 2.0.16-1.mga7
+ Revision: 1398993
- Update to version 2.0.16

* Mon Mar 11 2019 kekepower <kekepower> 2.0.15-1.mga7
+ Revision: 1373934
- Update to version 2.0.15

* Thu Jan 10 2019 daviddavid <daviddavid> 2.0.14-2.mga7
+ Revision: 1354081
- rebuild for new Python 3.7

* Sun Dec 23 2018 kekepower <kekepower> 2.0.14-1.mga7
+ Revision: 1344753
- Update to version 2.0.14

* Mon Dec 10 2018 kekepower <kekepower> 2.0.13-1.mga7
+ Revision: 1339763
- Update to version 2.0.13

* Thu Oct 11 2018 kekepower <kekepower> 2.0.12-2.mga7
+ Revision: 1319414
- Update to version 2.0.12

* Fri Sep 21 2018 umeabot <umeabot> 2.0.11-2.mga7
+ Revision: 1291997
- Mageia 7 Mass Rebuild

* Wed Sep 12 2018 kekepower <kekepower> 2.0.11-1.mga7
+ Revision: 1258742
- Update to version 2.0.11

* Wed May 23 2018 kekepower <kekepower> 2.0.8-1.mga7
+ Revision: 1231862
- Update to version 2.0.8

* Mon May 07 2018 kekepower <kekepower> 2.0.7-1.mga7
+ Revision: 1227207
- Update to version 2.0.7

* Wed Feb 21 2018 kekepower <kekepower> 1.9.15-2.mga7
+ Revision: 1203956
- Stripped source of files with wrong license
- BR python-sphinx if build with docs

* Wed Feb 21 2018 kekepower <kekepower> 1.9.15-1.mga7
+ Revision: 1203888
- Update to version 1.9.15
- Use pythonegg to include py modules
- Fixed file list

* Fri Aug 04 2017 philippem <philippem> 1.8.19-2.mga7
+ Revision: 1134774
- rebuild for Python3.6

* Tue Feb 16 2016 philippem <philippem> 1.8.19-1.mga6
+ Revision: 962674
- fix doc files list
- update to 1.8.19

* Sat Oct 31 2015 philippem <philippem> 1.8.16-1.mga6
+ Revision: 896980
- update to 1.8.16

* Wed Oct 07 2015 daviddavid <daviddavid> 1.8.12-2.mga6
+ Revision: 886857
- use new python macros
+ tv <tv>
- rebuild for python 3.5

* Fri Aug 28 2015 philippem <philippem> 1.8.12-1.mga6
+ Revision: 870605
- update to 1.8.12
+ eatdirt <eatdirt>
- Upgrade to version 1.8.9

* Wed Oct 15 2014 umeabot <umeabot> 1.7.16-5.mga5
+ Revision: 743151
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.7.16-4.mga5
+ Revision: 730719
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.7.16-3.mga5
+ Revision: 690261
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes
- s/uggests:/Recommends:/

* Sat May 31 2014 pterjan <pterjan> 1.7.16-2.mga5
+ Revision: 629218
- Rebuild for new Python

* Sun Mar 30 2014 philippem <philippem> 1.7.16-1.mga5
+ Revision: 610463
- update to 1.7.16

* Sat Mar 08 2014 philippem <philippem> 1.7.15-1.mga5
+ Revision: 601339
- update to 1.7.15

* Sat Oct 19 2013 umeabot <umeabot> 1.7.13-2.mga4
+ Revision: 534730
- Mageia 4 Mass Rebuild

* Fri Sep 13 2013 philippem <philippem> 1.7.13-1.mga4
+ Revision: 478677
- Update to 1.7.13.

* Wed Jul 03 2013 philippem <philippem> 1.7.11-2.mga4
+ Revision: 449996
+ rebuild (emptylog)

* Wed Jul 03 2013 philippem <philippem> 1.7.11-1.mga4
+ Revision: 449896
- update to 1.7.11

* Mon Mar 25 2013 philippem <philippem> 1.7.10-1.mga3
+ Revision: 405242
- update to new upstream, regression fix, python3_waf macro fix

* Mon Jan 14 2013 umeabot <umeabot> 1.7.8-2.mga3
+ Revision: 385590
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 23 2012 philippem <philippem> 1.7.8-1.mga3
+ Revision: 334154
- Update to 1.7.8

* Sat Dec 01 2012 philippem <philippem> 1.7.6-1.mga3
+ Revision: 324146
- update to 1.7.6
+ malo <malo>
- update RPM group

* Sun Sep 30 2012 fwang <fwang> 1.7.4-2.mga3
+ Revision: 300677
- update python abi support

* Sat Sep 29 2012 fwang <fwang> 1.7.4-1.mga3
+ Revision: 300351
- new version 1.7.4

* Sat Sep 29 2012 fwang <fwang> 1.7.0-2.mga3
+ Revision: 300310
- rebuild for new py 3.3

* Thu Aug 02 2012 kamil <kamil> 1.7.0-1.mga3
+ Revision: 278018
- new version 1.7.0

* Tue Jul 03 2012 kamil <kamil> 1.7.0-0.pre5.3.mga3
+ Revision: 267032
- split waf.macros into python2 and python3 version and package separately

* Mon Jul 02 2012 kamil <kamil> 1.7.0-0.pre5.2.mga3
+ Revision: 266838
- stop using want-rpath=0 parameter in waf.macros, it's not standard and interrupts build

* Mon Jul 02 2012 kamil <kamil> 1.7.0-0.pre5.1.mga3
+ Revision: 266582
- new version 1.7.0pre5

* Sat Jun 30 2012 kamil <kamil> 1.6.11-2.mga3
+ Revision: 265669
- add support for python3-waf in .macro

* Sat Jun 30 2012 kamil <kamil> 1.6.11-1.mga3
+ Revision: 265577
- new version 1.6.11
- add subpackage with the Python 3 build (inspired by Fedora)
- clean .spec a bit

* Tue Dec 20 2011 philippem <philippem> 1.6.10-1.mga2
+ Revision: 184943
- Update to 1.6.10
- Remove patch applied upstream
- Change summary

* Wed Nov 30 2011 philippem <philippem> 1.6.9-1.mga2
+ Revision: 174541
- Update to 1.6.9

* Sat Oct 22 2011 philippem <philippem> 1.6.8-1.mga2
+ Revision: 157381
- Update to 1.6.8.
- Move HTML documentation to a subpackage.

* Sat Feb 26 2011 philippem <philippem> 1.6.3-2.mga1
+ Revision: 61039
- remove not allowed docs (bad licence)

* Sat Feb 26 2011 philippem <philippem> 1.6.3-1.mga1
+ Revision: 60933
- imported package waf


* Sat Feb 26 2011 Philippe Makowski <makowski.mageia@gmail.com> 1.6.3-1mga1
- initial import
- Update to new version 1.6.3

* Fri Oct 29 2010 Michael Scherer <misc@mandriva.org> 1.5.19-2mdv2011.0
+ Revision: 590142
- rebuild for python 2.7

* Sun Oct 17 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1.5.19-1mdv2011.0
+ Revision: 586308
- update to new version 1.5.19

* Sun Aug 22 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1.5.18-1mdv2011.0
+ Revision: 571976
- update to new version 1.5.18
- rediff patch 1

* Mon Apr 05 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1.5.15-1mdv2010.1
+ Revision: 531573
- update to new version 1.5.15
- rediff patch 0

* Sun Mar 07 2010 Lev Givon <lev@mandriva.org> 1.5.14-1mdv2010.1
+ Revision: 515481
- Update to 1.5.14.

* Thu Feb 18 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1.5.12-1mdv2010.1
+ Revision: 507863
- update to new version 1.5.12

* Mon Feb 01 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1.5.11-1mdv2010.1
+ Revision: 499241
-- update to new version 1.5.11
- rediff patch 0

* Wed Nov 18 2009 Frederik Himpe <fhimpe@mandriva.org> 1.5.10-1mdv2010.1
+ Revision: 467287
- update to new version 1.5.10

* Wed Sep 02 2009 Frederik Himpe <fhimpe@mandriva.org> 1.5.9-1mdv2010.0
+ Revision: 425473
- update to new version 1.5.9

* Sat Jul 11 2009 Funda Wang <fwang@mandriva.org> 1.5.8-2mdv2010.0
+ Revision: 394731
- fix pthread linkage

* Sun Jun 14 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.5.8-1mdv2010.0
+ Revision: 385925
- update to new version 1.5.8

* Sat May 30 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.5.6-1mdv2010.0
+ Revision: 381343
- update to new version 1.5.6

* Fri May 01 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.5.5-1mdv2010.0
+ Revision: 369238
- update to new version 1.5.5
- rediff patch 0

* Mon Feb 02 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.5.3-1mdv2009.1
+ Revision: 336307
- update to new version 1.5.3

* Fri Jan 30 2009 Funda Wang <fwang@mandriva.org> 1.5.2-4mdv2009.1
+ Revision: 335640
- specify LINKFLAGS also.

* Sat Jan 03 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.5.2-3mdv2009.1
+ Revision: 323950
- fix install macro

* Sat Jan 03 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.5.2-2mdv2009.1
+ Revision: 323544
- fix typo in waf.macros

* Sat Jan 03 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.5.2-1mdv2009.1
+ Revision: 323515
- add specs and source files
- provide waf.macros for rpm building
- Patch0: fix installation of waf
- Created package structure for waf.

